==> kuserfeedback-0.9.90.tar.xz: kuserfeedback-0.9.90/src/console/analytics/analyticsview.h <==
/*
    Copyright (C) 2016 Volker Krause <vkrause@kde.org>

    Permission is hereby granted, free of charge, to any person obtaining
    a copy of this software and associated documentation files (the
    "Software"), to deal in the Software without restriction, including
    without limitation the rights to use, copy, modify, merge, publish,
    distribute, sublicense, and/or sell copies of the Software, and to
    permit persons to whom the Software is furnished to do so, subject to
    the following conditions:

    The above copyright notice and this permission notice shall be included
    in all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef KUSERFEEDBACK_CONSOLE_ANALYTICSVIEW_H
#define KUSERFEEDBACK_CONSOLE_ANALYTICSVIEW_H

#include <core/product.h>

#include <QVector>
#include <QWidget>

#include <memory>

class QAbstractItemModel;

namespace QtCharts {
class QChart;
}

namespace KUserFeedback {
namespace Console {

class Aggregator;
class AggregatedDataModel;
class DataModel;
class RESTClient;
class TimeAggregationModel;

namespace Ui
{
class AnalyticsView;
}

class AnalyticsView : public QWidget
{
    Q_OBJECT
public:
    explicit AnalyticsView(QWidget *parent = nullptr);
    ~AnalyticsView();

    void setProduct(const Product &product);
    void setRESTClient(RESTClient *client);

signals:
    void logMessage(const QString &msg);

private:
    void chartSelected();
    void updateChart();
    void updateTimeSliderRange();

    Aggregator* createAggregator(const Aggregation &aggr) const;

    void exportData();
    void importData();
    void exportChart();

    std::unique_ptr<Ui::AnalyticsView> ui;

    RESTClient *m_client = nullptr;
    DataModel *m_dataModel;
    TimeAggregationModel *m_timeAggregationModel;
    AggregatedDataModel *m_aggregatedDataModel;

    QVector<Aggregator*> m_aggregators;

    std::unique_ptr<QtCharts::QChart> m_nullSingularChart;
    std::unique_ptr<QtCharts::QChart> m_nullTimelineChart;
};
}
}

#endif // KUSERFEEDBACK_CONSOLE_ANALYTICSVIEW_H

==> kuserfeedback_1.2.0.orig.tar.xz: kuserfeedback-1.2.0/src/console/analytics/analyticsview.h <==
/*
    SPDX-FileCopyrightText: 2016 Volker Krause <vkrause@kde.org>

    SPDX-License-Identifier: MIT
*/

#ifndef KUSERFEEDBACK_CONSOLE_ANALYTICSVIEW_H
#define KUSERFEEDBACK_CONSOLE_ANALYTICSVIEW_H

#include <core/product.h>

#include <QVector>
#include <QWidget>

#include <memory>

class QAbstractItemModel;

#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
namespace QtCharts {
class QChart;
class QChartView;
}
using QtCharts::QChart;
using QtCharts::QChartView;
#else
class QChart;
#endif

namespace KUserFeedback {
namespace Console {

class Aggregator;
class AggregatedDataModel;
class DataModel;
class RESTClient;
class TimeAggregationModel;

namespace Ui
{
class AnalyticsView;
}

class AnalyticsView : public QWidget
{
    Q_OBJECT
public:
    explicit AnalyticsView(QWidget *parent = nullptr);
    ~AnalyticsView() override;

    void setProduct(const Product &product);
    void setRESTClient(RESTClient *client);

signals:
    void logMessage(const QString &msg);

private:
    void chartSelected();
    void updateChart();
    void updateTimeSliderRange();

    Aggregator* createAggregator(const Aggregation &aggr) const;

    void exportData();
    void importData();
    void exportChart();

    std::unique_ptr<Ui::AnalyticsView> ui;

    RESTClient *m_client = nullptr;
    DataModel *m_dataModel;
    TimeAggregationModel *m_timeAggregationModel;
    AggregatedDataModel *m_aggregatedDataModel;

    QVector<Aggregator*> m_aggregators;

    std::unique_ptr<QChart> m_nullSingularChart;
    std::unique_ptr<QChart> m_nullTimelineChart;
};
}
}

#endif // KUSERFEEDBACK_CONSOLE_ANALYTICSVIEW_H
